==> haskell-tasty-sugar-2.2.2.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-F04NhTMjDyH1bmfyw0k1lk-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-F04NhTMjDyH1bmfyw0k1lk-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  f2053427ac75a7cef5cb5349dde8234b
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-F04NhTMjDyH1bmfyw0k1lk-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-FjY9UStlqJaKVtTjBtSzl filepath-1.4.2.2
    kvitable-1.1.0.1-Hd12sjpfGVEJooafJtgs5Y
    logict-0.8.1.0-FOdRz8gwNjd8bneaHUC5Ar
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-CmtY07bno6e3Q2mVZUKdcs text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-LlY1HrcYP35AnM6djwPXGM
key:                  tasty-sugar-2.2.2.1-LlY1HrcYP35AnM6djwPXGM
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  38ed2763c512f8a3e29deedb425ad8a7
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-LlY1HrcYP35AnM6djwPXGM
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-FjY9UStlqJaKVtTjBtSzl filepath-1.4.2.2
    logict-0.8.1.0-FOdRz8gwNjd8bneaHUC5Ar
    optparse-applicative-0.18.1.0-79DXPPhnqn915zrePmz04b
    prettyprinter-1.7.1-CmtY07bno6e3Q2mVZUKdcs
    tasty-1.5-16X7rvH0dLEHZm2ROTxxDS
    tasty-sugar-2.2.2.1-F04NhTMjDyH1bmfyw0k1lk-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-sugar-2.2.2.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-sugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.2.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.2.1-KffPTi8efwT4SeWjCVNRq9-tasty-sugar-internal

key:
    tasty-sugar-2.2.2.1-KffPTi8efwT4SeWjCVNRq9-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  5a13d009c22c6073c39b35e4b0ec21fb
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.2.1-KffPTi8efwT4SeWjCVNRq9-tasty-sugar-internal

depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-GojcfmzmwTeH34ijQJEsOx filepath-1.4.2.2
    kvitable-1.1.0.1-1YhFBoFBDTA7apHJ1uTdCD
    logict-0.8.1.0-GiHsLAP6mZI2GBwd3yrh26
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-H1CnA9YdkYYkwP4aBwQ7e text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.2.1
visibility:           public
id:                   tasty-sugar-2.2.2.1-LCuc6JjIXl4FdTBXFGCTq
key:                  tasty-sugar-2.2.2.1-LCuc6JjIXl4FdTBXFGCTq
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  143b191e5a000d8046312aae4cf2aa03
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-sugar-2.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.2.1-LCuc6JjIXl4FdTBXFGCTq
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filemanip-0.3.6.3-GojcfmzmwTeH34ijQJEsOx filepath-1.4.2.2
    logict-0.8.1.0-GiHsLAP6mZI2GBwd3yrh26
    optparse-applicative-0.18.1.0-CKCQVkeW052FlPJiFlkCaf
    prettyprinter-1.7.1-H1CnA9YdkYYkwP4aBwQ7e
    tasty-1.5-GipkZ3gZ4qmGz8Rl0ke00W
    tasty-sugar-2.2.2.1-KffPTi8efwT4SeWjCVNRq9-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
